@@ -33,9 +33,10 @@
 #  define THREADWEAVER_DEPRECATED_NO_EXPORT THREADWEAVER_NO_EXPORT THREADWEAVER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define THREADWEAVER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef THREADWEAVER_NO_DEPRECATED
+#    define THREADWEAVER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
